@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: settings.py 12425 2020-07-26 06:31:20Z Bear $
+# $Id: settings.py 12410 2020-07-22 05:36:07Z Bear $
 #
 # Copyright (c) 2014 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Bear $
-# $Date: 2020-07-26 14:31:20 +0800 (週日, 26 七月 2020) $
-# $Revision: 12425 $
+# $Date: 2020-07-22 14:36:07 +0900 (週三, 22 七月 2020) $
+# $Revision: 12410 $
 
 import os
 import sys
@@ -35,7 +35,7 @@ import Iuno
 # Project settings.
 
 APP_NAME = 'mailworker'
-APP_VERSION = "0.4.1." + "$Revision: 12425 $"[11:-2]
+APP_VERSION = "0.4.1." + "$Revision: 12410 $"[11:-2]
  
 INSTALLED_APPS = (
     'django.contrib.auth',
@@ -112,11 +112,6 @@ IUNO_CLOUD_LOGGING_FILE = os.path.join(os.path.dirname(__file__), 'mail.log')
 #============================================================================
 ALLOWED_DOMAINS = ['extension.mail', ]
 
-IUNO_SITE_DOMAIN_NAMES = {
-    DEVELOPMENT: '', 
-    STAGE: '', 
-    PRODUCTION: ''
-}
 
 BASE_DIR = os.path.dirname(os.path.dirname(__file__))
 DATABASES = {
