@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12448 2020-08-06 05:52:30Z Lavender $
+# $Id: __init__.py 12484 2020-08-27 09:08:55Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,10 +12,11 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2020-08-06 14:52:30 +0900 (週四, 06 八月 2020) $
-# $Revision: 12448 $
+# $Date: 2020-08-27 18:08:55 +0900 (週四, 27 八月 2020) $
+# $Revision: 12484 $
 
 import os
+import re
 import sys
 import base64 
 import warnings
@@ -30,6 +31,8 @@ from collections import OrderedDict
 
 import twder
 
+from oscar.templatetags.currency_filters import currency
+
 from Iuppiter.Encoding import utf8
 from Iuppiter.Encryption import Encryptor
 from Iuppiter.DjangoUtil import DJANGO_VERSION, reverse
@@ -956,6 +959,9 @@ def buildAPIForm(submission, request, apiName, extra={}):
 
         itemName = utf8(itemName)
         
+        currencyStr = currency(total, submission['order_total'].currency).replace(",", "")
+        total = int(re.findall(r"[0-9\.]+", currencyStr)[0])
+        
     # merchantTradeNo
     basketId = basket.id
     tradeNo = 'BASKETID%d' % basketId
